Skip to content
KitploitKITPLOIT
StrumentiExploitsBlog
Log in
Invia
StrumentiExploitsBlog
Invia

Strumenti di Hacking, PenTest e Cybersecurity per il tuo Arsenale di Sicurezza!

Kitploit è una directory di strumenti di hacking, cybersecurity e pentesting. Scopri gli ultimi aggiornamenti dei progetti per trovare vulnerabilità, analizzare sistemi, automatizzare i test e rafforzare la tua sicurezza.

··Feed·Contatto·Privacy·© 2026 Kitploit

Directory degli strumenti

Categorie

Vedi tutte le categorie
Loading categories
MacMaster — Gestione e monitoraggio avanzati delle interfacce di rete | Kitploit
Strumenti/GitHubGitHub/halildeniz/macmaster
Sniffing e Analisi dei PacchettiAuditing Wi-FiRaccolta InformazioniSicurezza di RetePenetration Testing
GitHubhalildeniz/macmaster

MacMaster

Gestione e monitoraggio avanzati delle interfacce di rete

Vedi Repository
3410162 anni faRevisionato da Kitploit
Sito web

Più Popolari

Vedi tutti →

Scopri gli strumenti più utilizzati dalla nostra community.

Esplora tutti gli strumenti

Sfoglia la nostra collezione di strumenti

Vedi tutti gli strumenti →
Condividi

MacMaster: Gestione Avanzata delle Interfacce di Rete e Monitoraggio

MacMaster è uno strumento da riga di comando completo, progettato sia per professionisti di rete che per appassionati. Si distingue come un potente utility per manipolare gli indirizzi MAC delle interfacce di rete su vari sistemi. Progettato con semplicità e funzionalità in mente, MacMaster eccelle nel fornire soluzioni per migliorare l'anonimato di rete, condurre test di sicurezza ed eseguire un'ampia gamma di diagnostica e monitoraggio di rete. Che tu stia cercando di anonimizzare la tua presenza in rete, risolvere problemi di connettività o impegnarti in analisi avanzate di rete, MacMaster ti fornisce gli strumenti necessari per svolgere queste attività in modo efficiente.

Caratteristiche

  • Indirizzo MAC Personalizzato: Imposta un indirizzo MAC specifico sulla tua interfaccia di rete.
  • Indirizzo MAC Casuale: Genera e imposta un indirizzo MAC casuale.
  • Ripristino Originale: Ripristina l'indirizzo MAC al valore hardware originale.
  • OUI Personalizzato: Imposta un Identificativo Univoco dell'Organizzazione (OUI) personalizzato per l'indirizzo MAC.
  • Informazioni sulla Versione: Controlla facilmente la versione di MacMaster in uso.
  • Elenco Interfacce di Rete: Elenca facilmente tutte le interfacce di rete disponibili.
  • Cambio Modalità Interfaccia: Cambia le interfacce di rete wireless tra le modalità 'managed' e 'monitor'.
  • Ripristino Servizi di Rete: Ripristina rapidamente i servizi di rete per applicare modifiche o risolvere problemi.
  • Monitoraggio Traffico di Rete: Monitora il traffico MAC in tempo reale per analisi e test di sicurezza.

Installazione

MacMaster richiede Python 3.6 o successivo.

  1. Clona il repository:
    $ git clone https://github.com/HalilDeniz/MacMaster.git
    
  2. Spostati nella directory clonata:
    cd MacMaster
    
  3. Installa il pacchetto:
    $ python setup.py install
    

Utilizzo

$ macmaster.py --help
usage: macmaster.py [-h] [--interface INTERFACE] [--list-interfaces] [--version]
                    [--random | --newmac NEWMAC | --customoui CUSTOMOUI | --reset]
                    [--mode {managed,monitor,master,auto,repeater}] [--get-ssid] [--check-security]
                    [--analyze-signal] [--restart-network] [--monitor-mac-traffic] [--analyze-packets]

MacMaster: Advanced Network Interface Management and Monitoring

options:
  -h, --help            show this help message and exit
  --interface INTERFACE, -i INTERFACE
                        Network interface to change MAC address
  --list-interfaces, -li
                        List all network interfaces
  --version, -V         Show the version of the program
  --random, -r          Set a random MAC address
  --newmac NEWMAC, -nm NEWMAC
                        Set a specific MAC address
  --customoui CUSTOMOUI, -co CUSTOMOUI
                        Set a custom OUI for the MAC address
  --reset, -rs          Reset MAC address to the original value
  --mode {managed,monitor,master,auto,repeater}
                        Change interface mode to managed or monitor
  --get-ssid            Get the SSID of the wireless interface
  --check-security      Check the security protocol of the wireless interface
  --analyze-signal      Analyze the signal strength and quality of the wireless interface
  --restart-network, -rn
                        Restart network services
  --monitor-mac-traffic, -mmt
                        Live Monitor Mac traffic
  --analyze-packets, -ap
                        Analyze network packets on the interface

Argomenti

  • --interface, -i: Specifica l'interfaccia di rete da utilizzare per le operazioni sull'indirizzo MAC.
  • --random, -r: Genera e imposta un indirizzo MAC casuale sull'interfaccia specificata.
  • --newmac, -nm: Imposta un indirizzo MAC specifico sull'interfaccia specificata.
  • --customoui, -co: Imposta un Identificativo Univoco dell'Organizzazione (OUI) personalizzato per l'indirizzo MAC sull'interfaccia specificata.
  • --reset, -rs: Ripristina l'indirizzo MAC dell'interfaccia specificata al valore hardware originale.
  • --version, -V: Mostra la versione corrente di MacMaster.
  • --list-interfaces, -li: Elenca tutte le interfacce di rete disponibili sul sistema.
  • --mode, -m: Cambia la modalità di un'interfaccia di rete wireless (opzioni incluse 'managed', 'monitor', 'master', 'auto', 'repeater').
  • --restart-network, -rn: Riavvia i servizi di rete per applicare modifiche o risolvere problemi di rete.
  • --monitor-mac-traffic, -mmt: Monitora e visualizza il traffico MAC in tempo reale sull'interfaccia specificata.
  • --get-ssid, -gs: Mostra l'SSID della rete Wi-Fi connessa.
  • --analyze-signal, -as: Analizza la potenza e la qualità del segnale dell'interfaccia wireless.
  • --check-security, -cs: Controlla il protocollo di sicurezza dell'interfaccia wireless.
  • --analyze-packets, -ap: Analizza i pacchetti di rete sull'interfaccia.

Esempi

  1. Imposta un indirizzo MAC specifico:
    macmaster -i eth0 -nm 00:11:22:33:44:55
    
  2. Imposta un indirizzo MAC casuale:
    macmaster -i eth0 -r
    
  3. Ripristina l'indirizzo MAC al valore originale:
    macmaster -i eth0 -rs
    
  4. Elenca tutte le interfacce di rete:
    macmaster -li
    
  5. Cambia modalità dell'interfaccia:
    macmaster -i eth0 -m monitor
    
  6. Riavvia i servizi di rete:
    macmaster -rn
    
  7. Monitora il traffico MAC in tempo reale:
    macmaster -i eth0 -mmt
    

Nota

Devi eseguire questo script come root o utilizzare sudo affinché funzioni correttamente. Questo perché la modifica di un indirizzo MAC richiede privilegi di root.

Contribuire

I contributi sono benvenuti! Per contribuire a MacMaster, segui questi passaggi:

  1. Fai un fork del repository.
  2. Crea un nuovo branch per la tua funzionalità o correzione di bug.
  3. Apporta le tue modifiche e committale.
  4. Invia le modifiche al tuo repository forkato.
  5. Apri una pull request nel repository principale.

Contatto

Per qualsiasi richiesta o ulteriori informazioni, puoi contattarmi attraverso i seguenti canali:

Contatto

  • Linktr :Halil Deniz
  • LinkedIn : Halil İbrahim Deniz
  • TryHackMe : halilovic
  • Instagram : deniz.halil333
  • YouTube : HalilDeniz
  • Email: [email protected]

Licenza

MacMaster è rilasciato sotto licenza MIT. Vedi LICENSE per maggiori informazioni.

Scarica lo strumento